@@ -1,35 +1,49 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type EC2ClientVpnEndpoint struct {
-	svc     *ec2.EC2
-	id      string
-	cveTags []*ec2.Tag
-}
+const EC2ClientVpnEndpointResource = "EC2ClientVpnEndpoint"
 
 func init() {
-	register("EC2ClientVpnEndpoint", ListEC2ClientVpnEndoint)
+	registry.Register(&registry.Registration{
+		Name:     EC2ClientVpnEndpointResource,
+		Scope:    nuke.Account,
+		Resource: &EC2ClientVpnEndpoint{},
+		Lister:   &EC2ClientVpnEndpointLister{},
+		DependsOn: []string{
+			EC2ClientVpnEndpointAttachmentResource,
+		},
+	})
 }
 
-func ListEC2ClientVpnEndoint(sess *session.Session) ([]Resource, error) {
-	svc := ec2.New(sess)
-	resources := make([]Resource, 0)
+type EC2ClientVpnEndpointLister struct{}
+
+func (l *EC2ClientVpnEndpointLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := ec2.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 	params := &ec2.DescribeClientVpnEndpointsInput{}
 
 	err := svc.DescribeClientVpnEndpointsPages(params,
 		func(page *ec2.DescribeClientVpnEndpointsOutput, lastPage bool) bool {
-
 			for _, out := range page.ClientVpnEndpoints {
 				resources = append(resources, &EC2ClientVpnEndpoint{
 					svc: svc,
 					id:  *out.ClientVpnEndpointId,
 				})
 			}
+
 			return true
 		})
 	if err != nil {
@@ -39,7 +53,13 @@ func ListEC2ClientVpnEndoint(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (c *EC2ClientVpnEndpoint) Remove() error {
+type EC2ClientVpnEndpoint struct {
+	svc     *ec2.EC2
+	id      string
+	cveTags []*ec2.Tag
+}
+
+func (c *EC2ClientVpnEndpoint) Remove(_ context.Context) error {
 	params := &ec2.DeleteClientVpnEndpointInput{
 		ClientVpnEndpointId: &c.id,
 	}
@@ -52,9 +72,9 @@ func (c *EC2ClientVpnEndpoint) Remove() error {
 	return nil
 }
 
-func (e *EC2ClientVpnEndpoint) Properties() types.Properties {
+func (c *EC2ClientVpnEndpoint) Properties() types.Properties {
 	properties := types.NewProperties()
-	for _, tagValue := range e.cveTags {
+	for _, tagValue := range c.cveTags {
 		properties.SetTagWithPrefix("cve", tagValue.Key, tagValue.Value)
 	}
 	return properties
