@@ -1,36 +1,46 @@
 package resources
 
 import (
+	"context"
+
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type EC2VPNGatewayAttachment struct {
-	svc     *ec2.EC2
-	vpcId   string
-	vpnId   string
-	state   string
-	vpcTags []*ec2.Tag
-	vgwTags []*ec2.Tag
-}
+const EC2VPNGatewayAttachmentResource = "EC2VPNGatewayAttachment"
 
 func init() {
-	register("EC2VPNGatewayAttachment", ListEC2VPNGatewayAttachments)
+	registry.Register(&registry.Registration{
+		Name:     EC2VPNGatewayAttachmentResource,
+		Scope:    nuke.Account,
+		Resource: &EC2VPNGatewayAttachment{},
+		Lister:   &EC2VPNGatewayAttachmentLister{},
+		DeprecatedAliases: []string{
+			"EC2VpnGatewayAttachement",
+		},
+	})
 }
 
-func ListEC2VPNGatewayAttachments(sess *session.Session) ([]Resource, error) {
-	svc := ec2.New(sess)
+type EC2VPNGatewayAttachmentLister struct{}
+
+func (l *EC2VPNGatewayAttachmentLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := ec2.New(opts.Session)
 
 	resp, err := svc.DescribeVpcs(nil)
 	if err != nil {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, vpc := range resp.Vpcs {
 		params := &ec2.DescribeVpnGatewaysInput{
 			Filters: []*ec2.Filter{
@@ -49,8 +59,8 @@ func ListEC2VPNGatewayAttachments(sess *session.Session) ([]Resource, error) {
 		for _, vgw := range resp.VpnGateways {
 			resources = append(resources, &EC2VPNGatewayAttachment{
 				svc:     svc,
-				vpcId:   *vpc.VpcId,
-				vpnId:   *vgw.VpnGatewayId,
+				vpcID:   *vpc.VpcId,
+				vpnID:   *vgw.VpnGatewayId,
 				vpcTags: vpc.Tags,
 				vgwTags: vgw.Tags,
 			})
@@ -60,6 +70,15 @@ func ListEC2VPNGatewayAttachments(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type EC2VPNGatewayAttachment struct {
+	svc     *ec2.EC2
+	vpcID   string
+	vpnID   string
+	state   string
+	vpcTags []*ec2.Tag
+	vgwTags []*ec2.Tag
+}
+
 func (v *EC2VPNGatewayAttachment) Filter() error {
 	if v.state == "detached" {
 		return fmt.Errorf("already detached")
@@ -67,10 +86,10 @@ func (v *EC2VPNGatewayAttachment) Filter() error {
 	return nil
 }
 
-func (v *EC2VPNGatewayAttachment) Remove() error {
+func (v *EC2VPNGatewayAttachment) Remove(_ context.Context) error {
 	params := &ec2.DetachVpnGatewayInput{
-		VpcId:        &v.vpcId,
-		VpnGatewayId: &v.vpnId,
+		VpcId:        &v.vpcID,
+		VpnGatewayId: &v.vpnID,
 	}
 
 	_, err := v.svc.DetachVpnGateway(params)
@@ -93,5 +112,5 @@ func (v *EC2VPNGatewayAttachment) Properties() types.Properties {
 }
 
 func (v *EC2VPNGatewayAttachment) String() string {
-	return fmt.Sprintf("%s -> %s", v.vpnId, v.vpcId)
+	return fmt.Sprintf("%s -> %s", v.vpnID, v.vpcID)
 }
