@@ -1,24 +1,40 @@
 package resources
 
 import (
+	"context"
+
 	"fmt"
 
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type EC2VPNGateway struct {
-	svc   *ec2.EC2
-	id    string
-	state string
-}
+const EC2VPNGatewayResource = "EC2VPNGateway"
 
 func init() {
-	register("EC2VPNGateway", ListEC2VPNGateways)
+	registry.Register(&registry.Registration{
+		Name:     EC2VPNGatewayResource,
+		Scope:    nuke.Account,
+		Resource: &EC2VPNGateway{},
+		Lister:   &EC2VPNGatewayLister{},
+		DependsOn: []string{
+			EC2VPNGatewayAttachmentResource,
+		},
+		DeprecatedAliases: []string{
+			"EC2VpnGateway",
+		},
+	})
 }
 
-func ListEC2VPNGateways(sess *session.Session) ([]Resource, error) {
-	svc := ec2.New(sess)
+type EC2VPNGatewayLister struct{}
+
+func (l *EC2VPNGatewayLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := ec2.New(opts.Session)
 
 	params := &ec2.DescribeVpnGatewaysInput{}
 	resp, err := svc.DescribeVpnGateways(params)
@@ -26,7 +42,7 @@ func ListEC2VPNGateways(sess *session.Session) ([]Resource, error) {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, out := range resp.VpnGateways {
 		resources = append(resources, &EC2VPNGateway{
 			svc:   svc,
@@ -38,6 +54,12 @@ func ListEC2VPNGateways(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+type EC2VPNGateway struct {
+	svc   *ec2.EC2
+	id    string
+	state string
+}
+
 func (v *EC2VPNGateway) Filter() error {
 	if v.state == "deleted" {
 		return fmt.Errorf("already deleted")
@@ -45,7 +67,7 @@ func (v *EC2VPNGateway) Filter() error {
 	return nil
 }
 
-func (v *EC2VPNGateway) Remove() error {
+func (v *EC2VPNGateway) Remove(_ context.Context) error {
 	params := &ec2.DeleteVpnGatewayInput{
 		VpnGatewayId: &v.id,
 	}
