@@ -1,22 +1,34 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/opsworks"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type OpsWorksInstance struct {
-	svc *opsworks.OpsWorks
-	ID  *string
-}
+const OpsWorksInstanceResource = "OpsWorksInstance"
 
 func init() {
-	register("OpsWorksInstance", ListOpsWorksInstances)
+	registry.Register(&registry.Registration{
+		Name:     OpsWorksInstanceResource,
+		Scope:    nuke.Account,
+		Resource: &OpsWorksInstance{},
+		Lister:   &OpsWorksInstanceLister{},
+	})
 }
 
-func ListOpsWorksInstances(sess *session.Session) ([]Resource, error) {
-	svc := opsworks.New(sess)
-	resources := []Resource{}
+type OpsWorksInstanceLister struct{}
+
+func (l *OpsWorksInstanceLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := opsworks.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	stackParams := &opsworks.DescribeStacksInput{}
 
@@ -44,8 +56,12 @@ func ListOpsWorksInstances(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *OpsWorksInstance) Remove() error {
+type OpsWorksInstance struct {
+	svc *opsworks.OpsWorks
+	ID  *string
+}
 
+func (f *OpsWorksInstance) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteInstance(&opsworks.DeleteInstanceInput{
 		InstanceId: f.ID,
 	})
