@@ -1,23 +1,31 @@
 package resources
 
 import (
-	"github.com/aws/aws-sdk-go/aws/session"
+	"context"
+
 	"github.com/aws/aws-sdk-go/service/rds"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
 )
 
-type RDSProxy struct {
-	svc  *rds.RDS
-	id   string
-	tags []*rds.Tag
-}
+const RDSProxyResource = "RDSProxy"
 
 func init() {
-	register("RDSProxy", ListRDSProxies)
+	registry.Register(&registry.Registration{
+		Name:     RDSProxyResource,
+		Scope:    nuke.Account,
+		Resource: &RDSProxy{},
+		Lister:   &RDSProxyLister{},
+	})
 }
 
-func ListRDSProxies(sess *session.Session) ([]Resource, error) {
-	svc := rds.New(sess)
+type RDSProxyLister struct{}
+
+func (l *RDSProxyLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+	svc := rds.New(opts.Session)
 
 	params := &rds.DescribeDBProxiesInput{}
 	resp, err := svc.DescribeDBProxies(params)
@@ -25,7 +33,7 @@ func ListRDSProxies(sess *session.Session) ([]Resource, error) {
 		return nil, err
 	}
 
-	resources := make([]Resource, 0)
+	resources := make([]resource.Resource, 0)
 	for _, instance := range resp.DBProxies {
 		tags, err := svc.ListTagsForResource(&rds.ListTagsForResourceInput{
 			ResourceName: instance.DBProxyArn,
@@ -45,7 +53,13 @@ func ListRDSProxies(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (i *RDSProxy) Remove() error {
+type RDSProxy struct {
+	svc  *rds.RDS
+	id   string
+	tags []*rds.Tag
+}
+
+func (i *RDSProxy) Remove(_ context.Context) error {
 	params := &rds.DeleteDBProxyInput{
 		DBProxyName: &i.id,
 	}
