@@ -1,25 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/robomaker"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type RoboMakerRobotApplication struct {
-	svc     *robomaker.RoboMaker
-	name    *string
-	arn     *string
-	version *string
-}
+const RoboMakerRobotApplicationResource = "RoboMakerRobotApplication"
 
 func init() {
-	register("RoboMakerRobotApplication", ListRoboMakerRobotApplications)
+	registry.Register(&registry.Registration{
+		Name:     RoboMakerRobotApplicationResource,
+		Scope:    nuke.Account,
+		Resource: &RoboMakerRobotApplication{},
+		Lister:   &RoboMakerRobotApplicationLister{},
+	})
 }
 
-func ListRoboMakerRobotApplications(sess *session.Session) ([]Resource, error) {
-	svc := robomaker.New(sess)
-	resources := []Resource{}
+type RoboMakerRobotApplicationLister struct{}
+
+func (l *RoboMakerRobotApplicationLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := robomaker.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &robomaker.ListRobotApplicationsInput{
 		MaxResults: aws.Int64(30),
@@ -50,8 +60,14 @@ func ListRoboMakerRobotApplications(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *RoboMakerRobotApplication) Remove() error {
+type RoboMakerRobotApplication struct {
+	svc     *robomaker.RoboMaker
+	name    *string
+	arn     *string
+	version *string
+}
 
+func (f *RoboMakerRobotApplication) Remove(_ context.Context) error {
 	request := robomaker.DeleteRobotApplicationInput{
 		Application: f.arn,
 	}
