@@ -1,23 +1,35 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/storagegateway"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type StorageGatewayVolume struct {
-	svc *storagegateway.StorageGateway
-	ARN *string
-}
+const StorageGatewayVolumeResource = "StorageGatewayVolume"
 
 func init() {
-	register("StorageGatewayVolume", ListStorageGatewayVolumes)
+	registry.Register(&registry.Registration{
+		Name:     StorageGatewayVolumeResource,
+		Scope:    nuke.Account,
+		Resource: &StorageGatewayVolume{},
+		Lister:   &StorageGatewayVolumeLister{},
+	})
 }
 
-func ListStorageGatewayVolumes(sess *session.Session) ([]Resource, error) {
-	svc := storagegateway.New(sess)
-	resources := []Resource{}
+type StorageGatewayVolumeLister struct{}
+
+func (l *StorageGatewayVolumeLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := storagegateway.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &storagegateway.ListVolumesInput{
 		Limit: aws.Int64(25),
@@ -46,8 +58,12 @@ func ListStorageGatewayVolumes(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (f *StorageGatewayVolume) Remove() error {
+type StorageGatewayVolume struct {
+	svc *storagegateway.StorageGateway
+	ARN *string
+}
 
+func (f *StorageGatewayVolume) Remove(_ context.Context) error {
 	_, err := f.svc.DeleteVolume(&storagegateway.DeleteVolumeInput{
 		VolumeARN: f.ARN,
 	})
