@@ -1,26 +1,37 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/waf"
 	"github.com/aws/aws-sdk-go/service/wafregional"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-type WAFRegionalRegexMatchSet struct {
-	svc  *wafregional.WAFRegional
-	id   *string
-	name *string
-}
+const WAFRegionalRegexMatchSetResource = "WAFRegionalRegexMatchSet" //nolint:gosec,nolintlint
 
 func init() {
-	register("WAFRegionalRegexMatchSet", ListWAFRegionalRegexMatchSet)
+	registry.Register(&registry.Registration{
+		Name:     WAFRegionalRegexMatchSetResource,
+		Scope:    nuke.Account,
+		Resource: &WAFRegionalRegexMatchTuple{},
+		Lister:   &WAFRegionalRegexMatchSetLister{},
+	})
 }
 
-func ListWAFRegionalRegexMatchSet(sess *session.Session) ([]Resource, error) {
-	svc := wafregional.New(sess)
-	resources := []Resource{}
+type WAFRegionalRegexMatchSetLister struct{}
+
+func (l *WAFRegionalRegexMatchSetLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := wafregional.New(opts.Session)
+	resources := make([]resource.Resource, 0)
 
 	params := &waf.ListRegexMatchSetsInput{
 		Limit: aws.Int64(50),
@@ -50,7 +61,13 @@ func ListWAFRegionalRegexMatchSet(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
-func (r *WAFRegionalRegexMatchSet) Remove() error {
+type WAFRegionalRegexMatchSet struct {
+	svc  *wafregional.WAFRegional
+	id   *string
+	name *string
+}
+
+func (r *WAFRegionalRegexMatchSet) Remove(_ context.Context) error {
 	tokenOutput, err := r.svc.GetChangeToken(&waf.GetChangeTokenInput{})
 	if err != nil {
 		return err
